@@ -47,6 +47,9 @@ FAILEDOPERATION_INQUIRYPRICEFAILED = 'FailedOperation.InquiryPriceFailed'
 # 查询退换价格失败，找不到付款订单，请检查设备 `ins-xxxxxxx` 是否已过期。
 FAILEDOPERATION_INQUIRYREFUNDPRICEFAILED = 'FailedOperation.InquiryRefundPriceFailed'
 
+# 镜像状态繁忙，请稍后重试。
+FAILEDOPERATION_INVALIDIMAGESTATE = 'FailedOperation.InvalidImageState'
+
 # 请求不支持`EMR`的实例`ins-xxxxxxxx`。
 FAILEDOPERATION_INVALIDINSTANCEAPPLICATIONROLEEMR = 'FailedOperation.InvalidInstanceApplicationRoleEmr'
 
@@ -257,7 +260,7 @@ INVALIDPARAMETER_LOCALDATADISKNOTSUPPORT = 'InvalidParameter.LocalDataDiskNotSup
 # 不支持同时指定密钥登陆和保持镜像登陆方式。
 INVALIDPARAMETER_PARAMETERCONFLICT = 'InvalidParameter.ParameterConflict'
 
-# 不支持设置登陆密码。
+# 不支持设置登录密码。
 INVALIDPARAMETER_PASSWORDNOTSUPPORTED = 'InvalidParameter.PasswordNotSupported'
 
 # 指定的快照不存在。
@@ -293,6 +296,9 @@ INVALIDPARAMETERVALUE_BANDWIDTHPACKAGEIDMALFORMED = 'InvalidParameterValue.Bandw
 # 请确认指定的带宽包是否存在。
 INVALIDPARAMETERVALUE_BANDWIDTHPACKAGEIDNOTFOUND = 'InvalidParameterValue.BandwidthPackageIdNotFound'
 
+# 实例为基础网络实例，目标实例规格仅支持私有网络，不支持调整。
+INVALIDPARAMETERVALUE_BASICNETWORKINSTANCEFAMILY = 'InvalidParameterValue.BasicNetworkInstanceFamily'
+
 # 请确认存储桶是否存在。
 INVALIDPARAMETERVALUE_BUCKETNOTFOUND = 'InvalidParameterValue.BucketNotFound'
 
@@ -338,6 +344,9 @@ INVALIDPARAMETERVALUE_ILLEGALHOSTNAME = 'InvalidParameterValue.IllegalHostName'
 # 传参格式不对。
 INVALIDPARAMETERVALUE_INCORRECTFORMAT = 'InvalidParameterValue.IncorrectFormat'
 
+# 实例ID不合要求，请提供规范的实例ID，类似ins-xxxxxxxx，字母x代表小写字符或数字。
+INVALIDPARAMETERVALUE_INSTANCEIDMALFORMED = 'InvalidParameterValue.InstanceIdMalformed'
+
 # 不支持操作不同计费方式的实例。
 INVALIDPARAMETERVALUE_INSTANCENOTSUPPORTEDMIXPRICINGMODEL = 'InvalidParameterValue.InstanceNotSupportedMixPricingModel'
 
@@ -713,6 +722,12 @@ UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 # 指定的实例付费模式或者网络付费模式不支持共享带宽包
 UNSUPPORTEDOPERATION_BANDWIDTHPACKAGEIDNOTSUPPORTED = 'UnsupportedOperation.BandwidthPackageIdNotSupported'
 
+# 云服务器绑定了弹性网卡，请解绑弹性网卡后再切换私有网络。
+UNSUPPORTEDOPERATION_ELASTICNETWORKINTERFACE = 'UnsupportedOperation.ElasticNetworkInterface'
+
+# 不支持加密镜像。
+UNSUPPORTEDOPERATION_ENCRYPTEDIMAGESNOTSUPPORTED = 'UnsupportedOperation.EncryptedImagesNotSupported'
+
 # 异构机型不支持跨机型调整。
 UNSUPPORTEDOPERATION_HETEROGENEOUSCHANGEINSTANCEFAMILY = 'UnsupportedOperation.HeterogeneousChangeInstanceFamily'
 
@@ -728,6 +743,9 @@ UNSUPPORTEDOPERATION_INSTANCECHARGETYPE = 'UnsupportedOperation.InstanceChargeTy
 # 不支持混合付费模式。
 UNSUPPORTEDOPERATION_INSTANCEMIXEDPRICINGMODEL = 'UnsupportedOperation.InstanceMixedPricingModel'
 
+# 中心可用区和边缘可用区实例不能混用批量操作。
+UNSUPPORTEDOPERATION_INSTANCEMIXEDZONETYPE = 'UnsupportedOperation.InstanceMixedZoneType'
+
 # 请求不支持操作系统为`Xserver windows2012cndatacenterx86_64`的实例`ins-xxxxxx` 。
 UNSUPPORTEDOPERATION_INSTANCEOSWINDOWS = 'UnsupportedOperation.InstanceOsWindows'
 
@@ -755,6 +773,9 @@ UNSUPPORTEDOPERATION_INSTANCESTATEFREEZING = 'UnsupportedOperation.InstanceState
 # 请求不支持正在隔离状态的实例。
 UNSUPPORTEDOPERATION_INSTANCESTATEISOLATING = 'UnsupportedOperation.InstanceStateIsolating'
 
+# 不支持操作创建失败的实例。
+UNSUPPORTEDOPERATION_INSTANCESTATELAUNCHFAILED = 'UnsupportedOperation.InstanceStateLaunchFailed'
+
 # 请求不支持创建未完成的实例
 UNSUPPORTEDOPERATION_INSTANCESTATEPENDING = 'UnsupportedOperation.InstanceStatePending'
 
@@ -821,6 +842,9 @@ UNSUPPORTEDOPERATION_LOCALDISKMIGRATINGTOCLOUDDISK = 'UnsupportedOperation.Local
 # 从市场镜像创建的自定义镜像不支持导出。
 UNSUPPORTEDOPERATION_MARKETIMAGEEXPORTUNSUPPORTED = 'UnsupportedOperation.MarketImageExportUnsupported'
 
+# 不支持修改系统盘的加密属性，比如使用非加密镜像重装加密系统盘。
+UNSUPPORTEDOPERATION_MODIFYENCRYPTIONNOTSUPPORTED = 'UnsupportedOperation.ModifyEncryptionNotSupported'
+
 # 绑定负载均衡的实例，不支持修改vpc属性。
 UNSUPPORTEDOPERATION_MODIFYVPCWITHCLB = 'UnsupportedOperation.ModifyVPCWithCLB'
 
@@ -851,6 +875,12 @@ UNSUPPORTEDOPERATION_PUBLICIMAGEEXPORTUNSUPPORTED = 'UnsupportedOperation.Public
 # 当前镜像不支持对该实例的重装操作。
 UNSUPPORTEDOPERATION_RAWLOCALDISKINSREINSTALLTOQCOW2 = 'UnsupportedOperation.RawLocalDiskInsReinstalltoQcow2'
 
+# 实例使用商业操作系统，不支持退还。
+UNSUPPORTEDOPERATION_REDHATINSTANCETERMINATEUNSUPPORTED = 'UnsupportedOperation.RedHatInstanceTerminateUnsupported'
+
+# 请求不支持操作系统为RedHat的实例。
+UNSUPPORTEDOPERATION_REDHATINSTANCEUNSUPPORTED = 'UnsupportedOperation.RedHatInstanceUnsupported'
+
 # 不支持该地域
 UNSUPPORTEDOPERATION_REGION = 'UnsupportedOperation.Region'
 
